<?php
    function get_cart_data($connection, $user_id) {
        $output['result'] = false;
        $output['product_count'] = 0;
        $output['total_amount'] = 0;
        $output['items'] = [];
        $query = "select item_count,product_details.product_id, product_name, product_price, image FROM order_cart_items ";
        $query .= "JOIN product_details ON product_details.product_id = order_cart_items.product_id WHERE order_cart_items.user_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("s", $user_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $stmt->close();
        $output['product_count'] = $result->num_rows;
        if ($output['product_count'] > 0) {
            $output['result'] = true;
            while ($row = $result->fetch_assoc()) {
                array_push($output['items'], $row);
                $output['total_amount'] += ($row['item_count'] * $row['product_price']);
            }
        }
        return $output;
    }

    function get_product_count_in_cart($connection, $user_id, $product_id) {
        $count = 0;
        $query = "select item_count FROM order_cart_items WHERE user_id = ? AND product_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("ss", $user_id, $product_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $stmt->close();
        $result = $result->fetch_assoc();
        if ($result) {
            $count = $result['item_count'];
        }
        return $count;
    }

    function add_item_to_cart($connection, $user_id, $product_id) {
        $query = "INSERT INTO  order_cart_items(user_id,product_id,item_count) VALUES(?,?,?)";
        $stmt = $connection->prepare($query);
        $count = "1";
        $stmt->bind_param("sss", $user_id, $product_id, $count);
        $stmt->execute();
        $stmt->close();
    }

    function remove_item_from_cart($connection, $data) {
        $query = "DELETE FROM  order_cart_items  WHERE user_id = ? AND product_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("ss", $data['user_id'], $data['product_id']);
        $stmt->execute();
        $stmt->close();
    }

    function update_cart_item_count($connection, $user_id, $product_id, $item_count) {
        $query = "UPDATE order_cart_items SET item_count = ?  WHERE user_id = ? AND product_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("sss", $item_count, $user_id, $product_id);
        $stmt->execute();
        $stmt->close();
    }

    function add_address($connection, $data) {
        $query = "INSERT INTO  user_address(user_id, contact_name, contact_number, address, road_name,	pincode, city, near_by_location) VALUES(?,?,?,?,?,?,?,?)";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("ssssssss", $data['user_id'], $data['contact_name'], $data['contact_number'], $data['address'], $data['road_name'], $data['pincode'], $data['city'], $data['near_by_location']);
        $stmt->execute();
        $stmt->close();
    }

    function update_address($connection, $data) {
        $query = "UPDATE user_address SET user_id = ?, contact_name = ?, contact_number = ?, address = ?, road_name = ?,	pincode = ? ,city = ? ,near_by_location = ? WHERE address_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("sssssssss", $data['user_id'], $data['contact_name'], $data['contact_number'], $data['address'], $data['road_name'], $data['pincode'], $data['city'], $data['near_by_location'], $data['address_id']);
        $stmt->execute();
        $stmt->close();
    }

    function delete_address($connection, $data) {
        $query = "DELETE FROM user_address  WHERE address_id = ? AND user_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("ss", $data['address_id'], $data['user_id']);
        $stmt->execute();
        $stmt->close();
    }

    function clone_user_address($connection, $address_id) {
        $query = "INSERT INTO `order_address` (`user_id`, `contact_name`, `contact_number`, `address`, `road_name`, `pincode`, `city`, `near_by_location`) ";
        $query .= "SELECT `user_id`, `contact_name`, `contact_number`, `address`, `road_name`, `pincode`, `city`, `near_by_location` FROM user_address where address_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("s", $address_id);
        $stmt->execute();
        $new_address_id = $stmt->insert_id;
        $stmt->close();
        return $new_address_id;
    }

    function place_order($connection,$user_id,  $user_address_id, $cart_data, $payment_mode_id, $receipt_id = 0) {
        $date_time = date('Y-m-d H:i:s');
        $address_id = clone_user_address($connection, $user_address_id);
        $query = "INSERT INTO order_master (user_id, address_id, order_total, created_at,payment_mode_id, receipt_id) VALUES(?,?,?,?,?, ?)";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("ssssss", $user_id, $address_id, $cart_data['total_amount'], $date_time, $payment_mode_id, $receipt_id);
        $stmt->execute();
        $order_id = $stmt->insert_id;
        foreach ($cart_data['items'] as $item) {
          $query = "INSERT INTO order_items (order_id, product_id, item_count, product_price) VALUES(?,?,?,?)";
          $stmt = $connection->prepare($query);
          $stmt->bind_param("ssss", $order_id, $item['product_id'], $item['item_count'],  $item['product_price']);
          $stmt->execute();
          $stmt->close();
        }
        insert_order_status($connection, $order_id,1);
        clear_cart($connection, $user_id); 
    }

    function make_order_receipt($connection, $data) {
        $created_at = date('Y-m-d H:i:s');
        $query = "INSERT INTO order_receipt_razorpay (user_id, total_amount,created_at) VALUES(?,?,?)";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("sss", $data['user_id'], $data['total_amount'], $created_at);
        $stmt->execute();
        $order_receipt_id = $stmt->insert_id;
        $stmt->close();
        return $order_receipt_id;
    }

    function insert_order_status($connection,$order_id,  $status_id) {
        $created_at = date('Y-m-d H:i:s');
        $query = "INSERT INTO order_status_history (status_id, order_id, updated_at) VALUES(?,?,?)";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("sss", $status_id, $order_id, $created_at);
        $stmt->execute();
        $stmt->close();
    }

    function update_order_receipt($connection, $data) {
        $created_at = date('Y-m-d H:i:s');
        $query = "UPDATE order_receipt_razorpay SET razorpay_payment_id = ?, razorpay_order_id = ?, razorpay_signature = ?,  ";
        $query .= "is_captured = 1,updated_at = ?  WHERE receipt_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("sssss", $data['razorpay_payment_id'], $data['razorpay_order_id'], $data['razorpay_signature'], $created_at, $data['receipt_id']);
        $stmt->execute();
        $stmt->close();
    }

    function clear_cart($connection, $user_id) {
        $query = "DELETE FROM `order_cart_items` WHERE `user_id` = ? ";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("s", $user_id);
        $stmt->execute();
        $stmt->close();
    }


    function cancel_order($connection, $user_id, $order_id) {
        $query = "UPDATE order_master SET status_id = 0 WHERE order_id = ? AND user_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("ss", $order_id, $user_id);
        $stmt->execute();
        $stmt->close();
        insert_order_status($connection, $order_id, 0);
    }

    function get_order_data($connection, $order_id) {
        $output['result'] = false;
        $output['items'] = [];
        $query = "select * FROM order_master WHERE order_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("s", $order_id);
        $stmt->execute();
        $result = $stmt->get_result();
        $stmt->close();
        if ($result->num_rows > 0) {
            if($output_temp = $result->fetch_assoc()){
              $output = $output_temp;
              $output['result'] = true;
              $output['items'] = get_order_item($connection, $order_id); 
            }
        }
        return $output;
    }

    function get_order_item($connection, $order_id){
        $items= [];
        $query = "select item_count,product_details.product_id, product_name, order_items.product_price, image FROM order_items ";
        $query .= "JOIN product_details ON product_details.product_id = order_items.product_id WHERE order_items.order_id = ?";
        $stmt = $connection->prepare($query);
        $stmt->bind_param("s", $order_id);
        $stmt->execute();
        $result = $stmt->get_result();
        if ($result->num_rows > 0) {
            while ($row = $result->fetch_assoc()) {
                array_push($items, $row);
            }
        }
        $stmt->close();
        return $items;
    }

